@@ -377,6 +377,7 @@ def identify_tit_sites(f_in, chains, nomenclature="PDB", add_ser_thr=False):
     nline = 0
     resnumb = None
     resname = None
+    skip_NTR = {chain: False for chain in chains}
     for line in content:
         nline += 1
         if line.startswith("ATOM "):
@@ -402,9 +403,12 @@ def identify_tit_sites(f_in, chains, nomenclature="PDB", add_ser_thr=False):
                     if resnumb not in chain_sites:
                         if (
                             not chain_res[chain]
-                            and resname != "PRO"
                             and aname in ("H1", "H2", "H3", "N")
+                            and not skip_NTR[chain]:
                         ) or (aname in ("H1", "H2", "H3")):
+                            if resname == "PRO":
+                                skip_NTR[chain] = True
+                                continue
                             chain_res = add_site(chain_res, chain, resnumb, "NTR")
 
                         if (
